from taibun.taibun import Converter
from utils import checker, bilabial_c, alveolar_c, alveolo_palatal_c, velar_c, front_c, central_c, back_c, nasal_c, stop_c, syllabic_c, additional_c

c = Converter(system="Zhuyin", punctuation='none')
c_north = Converter(system="Zhuyin", dialect="north", punctuation='none')

def test_zhuyin_initials():
    bilabial = ['ㄅㄧ','ㄆㄜ','ㄇㆦˊ','ㆠㄚˊ']
    checker(list(zip(bilabial_c, bilabial)), c, c_north)
    alveolar = ['ㄉㆤ˫/ㄉㄨㆤ˫','ㄊㄜ˪','ㄗㄚˋ','ㄘㄨ˪','ㄙㄨ','ㄋㄞ˫','ㆡㄨˊ/ㄌㄨˊ','ㄌㄧㄨˋ']
    checker(list(zip(alveolar_c, alveolar)), c, c_north)
    alveolo_palatal = ['ㄐㄧㄚ','ㄑㄧㄨˋ','ㄒㄧㄚˋ','ㆢㄧˊ/ㄌㄧˊ']
    checker(list(zip(alveolo_palatal_c, alveolo_palatal)), c, c_north)
    velar = ['ㄍㄧㄨˊ','ㄎㄧ˪','ㄫㄚˋ','ㆣㄧˋ/ㆣㄨˋ','ㄏㄧˋ']
    checker(list(zip(velar_c, velar)), c, c_north)

def test_zhuyin_vowels_and_rhymes():
    front = ['ㄧ','ㆤ˫','ㆪˊ','ㆥˊ']
    checker(list(zip(front_c, front)), c, c_north)
    central = ['ㄜ','ㄚ','ㆩ˫']
    checker(list(zip(central_c, central)), c, c_north)
    back = ['ㄨˋ','ㆦ','ㄉㄧㆫ','ㆧ']
    checker(list(zip(back_c, back)), c, c_north)

def test_zhuyin_finals():
    nasal = ['ㄧㆬ','ㄧㄣˊ','ㄤˊ']
    checker(list(zip(nasal_c, nasal)), c, c_north)
    stop = ['ㄧㄚㆴ˙','ㄚㆵ','ㆦㆶ','ㄚㆷ˙']
    checker(list(zip(stop_c, stop)), c, c_north)
    syllabic = ['ㆬˋ','ㆭˊ']
    checker(list(zip(syllabic_c, syllabic)), c, c_north)

def test_zhuyin_syllables_additional():
    additional = ["ㄗㆩ˫","ㄧㆵ ㄎㄞ˪","ㄙㆰ ㄗㄢ˪","ㄅㄨㆵ ㄙㄨㆵ","ㄊㄧㄨˋ","ㄉㆱˊ","ㄏㆧ","ㄎㄧㆵ ㄐㄧㄚㆷ˙","ㄌㄨㄢ˫ ㄐㄧㄥ","ㄍㄚ ㄌㄠㆷ˙","ㆢㄧㄣˊ ㄍㄢ/ㄌㄧㄣˊ ㄍㄢ","ㆣㄧㆲˋ ㄍㄚㆶ","ㄏㄧㄨ ㄎㄧㆶ","ㆠㄨˋ ㆢㄧㆦㆶ˙/ㆠㄨˋ ㄌㄧㆦㆶ˙","ㄊㄧㄥˊ ㄉㄧㄢ˫","ㆮ˫/ㄧㄤ˫","ㄊㄨㄢˊ ㄐㄧㄚㆴ","ㄏㄧㄠ ㄏㄧㄥ˫","ㆣㄧㆰˋ ㄫㆤ˫/ㆣㄧㆰˋ ㄫㄧ˫","ㄏㄧㆩ ㄍㄜ","ㄑㄧㆲ ㄗㆦㆶ","ㆠㄧㄢˋ ㄏㄨㄧ˪","ㆢㄧㆴ˙ ㄎㄠˋ/ㄌㄧㆴ˙ ㄎㄠˋ","ㄅㄚㆵ ㄒㄧㄢ","ㄅㆤㆷ ㆣㄨㆤㆷ˙ ㄗㆤㆷ/ㄅㄨㆤㆷ ㆣㆤㆷ˙ ㄗㄨㆤㆷ","ㄆㆩ˪ ㄆㄨㆷ˙","ㄅㄧㄥ ㄆㄠㆷ˙","ㄉㆮˋ","ㄆㄨㆩ˪ ㄉㄨㄢ˪","ㄅㄧㄚㆵ˙ ㄗㆲ","ㄍㄨㆤㆷ/ㄍㄨㄧㆷ","ㄊㄚㆶ ㄊㄧㆶ","ㄍㄚㆵ ㄌㆤˋ","ㄨㆤㆷ˙/ㄨㄧㆷ˙","ㄍㄚ ㄎㄨㄞ˪","ㄌㄨㄚㆵ˙","ㄍㄧㄚㆴ ㄍㄨㄢ","ㄘㆲ ㄑㄧㆦㆶ","ㄆㄧㆵ ㄉㄧㆶ˙","ㄅㄨㄢ˪ ㄙㄨㄧ˫","ㄏㄧㄚㆴ˙ ㄏㄜˊ","ㄎㄚㆷ ㄆㆪ˪","ㆠㄠˋ ㄇㄧㄚˊ","ㄇㄠㆷ ㄌㄜㆷ˙ ㄎㄧ˪","ㆣㄨㄧˊ ㄏㄧㆰˋ","ㄋㆭ˫ ㄅㄠ","ㄘㆰ ㄐㄧㄠ˪","ㄏㄚㆴ˙ ㄏㄨㄢ","ㄏㆰˊ ㄊㄧㆦㆶ","ㄎㆭㆷ","ㄎㄧㆴ ㄍㄨㆩ˫","ㆠㄨㄣˋ ㄑㄧㄜ˪","ㆤㆷ ㄙㆭ","ㄎㄨㆷ","ㄆㄧㄣˋ ㄒㄧㆲˊ","ㄏㄚㆷ ㄑㄧㆫ˪","ㄏㄚ ㄎㄨㄧ˪","ㄏㆮ ㄘㄢ","ㄏㄞㆷ","ㄎㆥㆷ˙","ㄋㄠㆷ","ㄧㆯ","ㆦ","ㄏㄨㄚㆷ ㄌㄧㄥ˫","ㄙㆩㆷ","ㄆㆭㆷ","ㄗㄚㆶ˙","ㄘㄠㆷ˙ ㄘㄠㆷ˙ ㄌㄧㆰ˫","ㄏㄠ ㄒㄧㄠˊ","ㄨㆷ","ㄞㆷ","ㄏㆬㆷ˙","ㄏㆤㆷ ㄍㄧㆩ","ㄑㄧㄚㆶ˙","ㆢㄧㄤˋ/ㄌㄧㆲˋ","ㄨㄤ","ㄉㄨㄣˋ ㄉㄧㄚㆷ˙","ㄎㄨㄣ˪ ㄍㄧㆦㆶ˙","ㆪˊ ㄙㆱ","ㄗㄞ˫","ㄊㄨㄣ˫ ㄊㆦˊ","ㄎㆥ ㄍㆦㆶ/ㄎㆪ ㄍㆦㆶ","ㄧㄥ ㄧㄚ","ㄌㄚㆷ ㄙㄚㆴ","ㄍㄧ ㄍㄧㆬ","ㆣㄧㄠˊ ㄍㄨˋ","ㄊㄚㆴ ㄊㆤ˪/ㄊㄚㆴ ㄊㄨㆤ˪","ㄅㄧㄚㆷ ㄨㆤ˫","ㄚㆴ ㆠㆦˊ","ㆣㄨㆤ˫ ㄒㄧㄥ","ㄉㄨㄚ˫ ㄙㄨㆩ","ㄊㆪ ㄍㆭ","ㄊㄧㄢ ㄏㄧㄜ˫","ㄊㄞ˪ ㄌㆦˋ ㄍㄜㆷ","ㄧㄤ ㄍㄧㆴ˙","ㄎㄧㄚ ㄒㄧㄤ","ㄆㄨㄣ ㄙㆲ","ㄏㆧ˪ ㄎㆤㆷ","ㄇㄧㄠ˫","ㄗㆭ ㄊㆩ˫","ㄑㄧㄚㆴ","ㄙㆥ˪/ㄒㆪ˪","ㄇㄚ ㄇㄚ","ㄅㄨ˫","ㄏㄚㆶ˙ ㄏㆭˊ","ㄜㆷ˙ ㄆㆮˋ/ㄜㆷ˙ ㄆㄞˋ","ㆣㄧㄚㆵ˙","ㄊㆤㆷ˙","ㄢ ㆠㄧㄣˊ","ㄍㄧㄚ˪ ㄌㄞˊ","ㆠㄚㆵ˙ ㄗㄚㆵ˙","ㄗㄨㄢ ㄨㄢˊ","ㆢㄧㄜ˫ ㄍㆦˋ/ㄌㄧㄜ˫ ㄍㆦˋ","ㄆㄨㄧ˪","ㄍㄞ˪ ㄒㄧˊ","ㄎㄨㆵ ㄍㄧㄜˊ","ㄅㄧㄣˊ ㄐㄧㄚ ㄋㄚˋ","ㄍㄧㄚㆷ˙","ㆣㆰˊ ㄧㆰˊ","ㆣㄚㆶ˙ ㄏㄨ˫","ㄋㄧˊ ㄅㄧㄜˋ","ㄉㄧㆰ˪ ㄗㆦ","ㆰ ㆠㄧㄜ˫","ㆢㄧㄚㆴ˙/ㄌㄧㄚㆴ˙","ㄅㄧㄨ","ㄏㄧㆵ ㄧㆫ˫","ㄎㄧㄜ˪","ㆢㄧㆬˋ ㄒㄧㆬ/ㄌㄧㆬˋ ㄒㄧㆬ","ㄎㄨㆪ˪ ㄨㄚㆷ˙","ㄏㄨㆵ ㆢㄧㄢˊ/ㄏㄨㆵ ㄌㄧㄢˊ","ㄆㆥ˫","ㄎㄧㄚㆴ ㄉㆩˋ","ㄎㄧㆲˋ ㄨㄧ˪","ㄒㄧㄜㆷ ㄌㄧㄜㆷ˙","ㆣㆦㆶ˙","ㆣㄤ˫","ㄘㆤㆷ ㄒㄧㆬ/ㄘㄨㆤㆷ ㄒㄧㆬ","ㄉㄢ˫","ㄋㆦ˫","ㄏㄨㄞˊ ㄌㄧㆰ˫","ㆣㆲ˫","ㄅㆤ ㄅㆭ˫","ㄫㄧㄨˋ ㄎㄚ ㄘㆭ","ㆢㄧㄠ˪ ㄐㄧㆫ˫/ㄌㄧㄠ˪ ㄐㄧㆫ˫","ㄆㄧ ㄉㄧㆩˊ","ㆠㄨㄚㆷ ㄏㄨㄣˋ","ㄎㄧㄜㆷ ㄒㄧㆴ˙","ㄊㄧㄚㆷ ㄉㄨㆩˊ","ㄆㄠ ㄘㄨㆵ","ㄆㄚ ㄙㄚ","ㄆㄚㆷ ㄘㄚㆴ","ㄊㄨㄚ ㄉㄧㆵ˙","ㄐㄧㄜ ㄨㄚˋ","ㄍㄨㄚㆷ ㄌㄠˊ","ㄗㆮˋ","ㄊㄚ˪","ㄏㆪ˪ ㄙㄚㆶ","ㄞ ㆣㄜ˫","ㄏㄧㄢ ㄘㆤㆷ","ㄙㄠ˪ ㄉㆲ˫","ㄉㄨㄚㆷ","ㄐㄧㆩ˫","ㆱ ㆠㄚㆶ˙ ㄍㆤ/ㆱ ㆠㄚㆶ˙ ㄍㄨㆤ","ㄘㄚㆷ ㄘㄨㄣ","ㄉㄨㆷ˙","ㄉㄧㄨㆷ","ㄉㄚㆷ ㄏㄧㆩㆷ","ㄉㄚㆷ ㄌㄧˋ ㆠㄨ˫","ㄎㆯㆷ˙","ㄆㄧㄚㆵ ㄑㄧㄥ","ㄫㄧㄠˋ","ㄊㄧㄚㆵ ㄐㄧㆵ","ㄉㄧㄚㆶ˙","ㄉㆰ ㄉㆭ","ㄆㄧㄚㆶ˙","ㄆㄢ ㄉㄧㄥ","ㄋㄨㄚˊ ㄗㄚㆷ˙","ㄎㆮˋ","ㄊㄧㄣˊ ㄐㄧㄨˋ","ㄏㆲ ㄏㄧㄥ ㆠㄧ˫ ㄫㄞ˫","ㄗㄜㆷ˙","ㆠㄨㄢˋ ㄏㄨㆤ˫/ㆠㄨㄢˋ ㄏㆤ˫","ㄗㆥˊ/ㄐㆪˊ","ㄋㆤˊ","ㄎㄧㆦㆶ ㄙㄨㆩ˪","ㄌㆲˋ ㄊㆦㆶ˙","ㆠㆦㆶ˙ ㆣㄧㄚㆴ˙","ㆠㄨㄚㆵ˙ ㄌㆦ˫","ㄊㄨˋ","ㄍㄨㄞˋ","ㆢㄧㆰˋ/ㄌㄧㆰˋ","ㄍㄠ˪ ㄨㄚㆵ˙","ㄏㄧㆶ˙ ㄎㄜˋ","ㄉㄜㆷ ㄊㄨㄚㆷ","ㆢㄧㄨˊ/ㄌㄧㄨˊ","ㄅㄧㄠ ㄅㄨㄣˋ","ㄆㄜㆷ ㄒㄧㆵ˙","ㄏㄨㆮˊ ㄍㆤㆷ˙/ㄏㄨㆪˊ ㄍㆤㆷ˙","ㄙㄨㆮ˫","ㄙㄨㆷ","ㄏㄧㄜㆷ ㄧㆩˋ","ㄍㄨㄚ ㄆㆦˋ","ㄏㄨㆩ ㄉㆦ˫","ㄨㄞ ㄘㄨㄚㆷ˙","ㄇㄨㄧˋ ㄅㄞˋ","ㄚㆶ ㄏㆦ˫","ㄉㄧㆬˊ ㄉㄧㆦㆶ˙","ㆠㄨㆵ˙ ㄧㄜㆷ˙","ㄉㄠㆷ˙","ㄉㄚㆴ˙ ㄉㄧㆷ","ㄑㄧㄤˊ ㄗㄨㄧˋ","ㄆㄨㆤㆷ˙/ㄆㆤㆷ˙","ㄏㄞˋ ㄏㆤ˫","ㄌㄧㄤˊ ㄎㄧㆲ","ㄊㄧㆰ ㄒㄧㄚㆵ","ㆠㄧㄠˋ ㆠㆲˊ","ㄊㄨㆩ˪ ㄗㄤˊ","ㆠㄧㄚㆵ˙ ㆠㄜˊ","ㄆㄧㄠ ㄆㄨˊ","ㄌㆦㆶ ㄙㄞˋ","ㄠ ㄅㄨㄧˊ","ㄐㄧㄤ","ㄆㄨㄚㆷ ㄒㆪ˪","ㄆㄨㄚㆵ ㄐㄧㄢ˫","ㆡㄨㄣ˫ ㄅㄧㆩˋ/ㄌㄨㄣ˫ ㄅㄧㆩˋ","ㄏㆯㆷ˙","ㄍㄧㆶ ㄌㄚㆵ˙","ㄗㄨㆩ˫","ㄅㄧㄚㆶ","ㄙㄚㆷ˙","ㄇㄨㆤˊ","ㄏㆩㆷ","ㄏㄧㆬˊ","ㆢㄧㄚㆵ˙ ㄌㄧㄚㆵ˙/ㄌㄧㄚㆵ˙ ㄌㄧㄚㆵ˙","ㄋㄚㆷ","ㄉㄧㄚ","ㄊㆥ˪","ㆣㄧㄨˊ ㄑㄧㆶ","ㄇㄧㆷ˙/ㄇㆭㆷ˙","ㄇㄧㆷ ㄉㄞ˫","ㄎㄧㄢ ㄍㄧㆲˊ","ㄎㄢ ㄎㄚㆴ˙","ㆠㄧㄥˋ ㄧㆲˋ","ㆣㄧㆶ˙ ㄎㄨㄢˊ","ㆣㄧㄜㆶ˙ ㄌㄢˊ","ㆣㄨㄢˋ ㄎㄨ˫","ㄍㆰ ㄎㆦˋ","ㄌㄨㆵ ㄇㆭˊ","ㄏㄢ ㄐㄧˊ/ㄏㄢ ㄗㄨˊ","ㄊㄧㄚㆴ˙ ㄐㄧㆰ","ㄙㆦ ㄙㄢ˪","ㆣㄧㄢ˪ ㄍㄚㆷ","ㄅㄚㆷ ㄅㄨㆩ","ㄧㆶ ㄊㄧㆲˊ","ㄧㄚㆷ ㄍㄜㆷ","ㄍㆩ ㄌㄜˊ","ㄒㄧㄜ ㄒㄧㆰˋ","ㆠㄞˊ ㄏㄧㄚㆷ˙","ㄎㄨㆩ˪","ㄏㄧㄣˊ ㄙㄨㄚ","ㄘㄨㆷ","ㆣㄢˋ ㄏㆦㆶ","ㄍㆮˊ","ㄉㆦㆶ ㄘㄚㆵ","ㄎㆤㆷ/ㄎㄨㆤㆷ","ㄍㄧㆷ","ㆣㄧㄥˋ ㄅㄨㄚㆷ","ㄆㄨㄚ˪ ㄎㄧㆷ","ㄉㆤㆷ","ㄨㆩˋ ㄊㄠˊ ㄉㄧ˫ ㆠㄨㆤˋ/ㄨㆩˋ ㄊㄠˊ ㄉㄨ˫ ㆠㆤˋ","ㄆㄧㆶ ㄊㆰˊ","ㄎㄚㆶ ㄅㄜˋ","ㆠㄨㄚˊ ㄎㆩ","ㄉㄚ ㄐㄧㄜㆷ˙","ㄘㆦˋ","ㆣㄞ˫ ㄉㄧㄜㆷ˙","ㄆㄧㄜ˪ ㄒㄧㆫ","ㄊㄨㆵ","ㄎㄤ ㄎㄤ","ㄉㄨㆵ˙","ㄌㆤㆷ˙/ㄌㄨㆤㆷ˙","ㄅㄧㆵ ㄙㄨㄢ˪","ㄘㆦㆶ","ㄅㄨㄚ˪","ㄑㄧㆰ ㆲˊ","ㄌㄧㄚㆴ˙","ㄎㆭ ㄘㆭ","ㄊㄧㄜ˪","ㄉㄧㄨ˫","ㄌㄚㆴ˙ ㄘㄞˋ","ㄙㄜㆷ ㄊㄨㄧ","ㄌㄨㄧˋ ㄐㄧㆶ","ㄎㆲˋ","ㄍㄧㄚㆵ ㄅㄚ","ㄗㄨㄚㆵ˙ ㄉㄨㄧ˪","ㆢㄧㆲˊ ㄅㆦ˪/ㄌㄧㆲˊ ㄅㆦ˪","ㄍㆥ ㄍㄧㄢˋ/ㄍㆪ ㄍㄧㄢˋ","ㄌㄧㆶ˙ ㄒㄧㆶ","ㄑㄧㆴ ㄅㆦˋ","ㄊㆲ˫","ㄅㄧㄢ ㄘㄨㄢ˪","ㄎㄨㄚㆵ ㄋㄧㄨˊ","ㆠㄧˋ ㆠㄧ˫","ㄏㄧㆴ ㆡㄨㄚㆷ˙/ㄏㄧㆴ ㄌㄨㄚㆷ˙","ㄆㄧㄥ˪ ㄑㄧㆩˋ","ㄊㄧㆩ ㄘㄜ˪","ㆠㄚㆷ ㆠㄚㆶ˙","ㄇㆤㆷ˙ ㄆㆦㆶ","ㄊㄨㄚㆵ ㄐㄧㄚㆵ","ㄎㄧㆫ ㄉㄧㄠ˫","ㄧㄜ ㄍㄨㆵ","ㄍㄧㄜㆷ ㄐㆪˊ","ㄗㄨㄣˊ ㄨㄣ˫","ㄒㄧㆶ ㆣㄚˊ","ㄇㄠˊ ㄘㄠˋ","ㄘㄠˋ ㄌㆤㆷ˙ ㄚˋ/ㄘㄠˋ ㄌㄨㆤㆷ˙ ㄚˋ","ㄫㆤㆷ","ㄌㄚㆶ ㄌㄜㆷ˙","ㄑㄧㄜㆷ˙","ㄘㄤ ㄫㄠ˫","ㄍㄨㆤㆷ ㄋㄧㄠ","ㄅㆦㆶ˙ ㄊㄞ˫","ㄅㄜㆷ˙ ㄇㆦㆷ˙","ㄍㄧㆫ","ㄏㄧㄠㆷ","ㄆㄨㄢ ㄅㄧㄣˊ","ㄎㄧㄥ˫","ㄗㄨㄚㆷ˙","ㄍㄚㆴ ㄌㄚˊ","ㄒㄧㆦㆶ˙ ㄑㄧㆵ","ㆣㄧㄚˊ ㄍㄤ","ㆠㄧㆵ˙ ㆣㄨㄚㆵ˙","ㄒㄧㆷ˙ ㄑㄧㄣ˪","ㆠㄨㄧ","ㄙㄚㆵ","ㆣㄧㄜˊ ㄅㄨㆤ","ㄫㄧㄠㆷ˙ ㄫㄧㄠㆷ˙ ㄉㄤ˫","ㄐㄧㆬˊ","ㄊㄢ ㄆㄧㆩˊ","ㆠㄤˋ ㄉㄠ˪","ㄑㄧㆷ˙","ㆠㄢˊ ㄆㄨㆤˊ ㄅㆥ˫/ㆠㄢˊ ㄆㆤˊ ㄅㆪ˫","ㄏㄨㆤㆷ ㄧㄨˊ/ㄏㄨㄧㆷ ㄧㄨˊ","ㄏㄧㄚㆵ ㄧㄢˊ","ㄌㄧㆷ˙ ㄆㄤ˫","ㄌㄧㄚㆷ ㄎㄧㄚㆷ","ㄊㆭ˪","ㄊㄧˋ ㄉㄨㄚㆵ˙","ㄎㄧㆬ ㄐㄧㆲ","ㆠㄨㆤㆷ˙ ㄙㆦㆶ","ㄍㄨㄧ ㄇㆤˊ/ㄍㄨㄧ ㄇㄧˊ","ㆠㄧㆷ ㄘㄨㄧ˪","ㄉㄚㆶ ㄉㆪˊ","ㄍㄨㄚㆵ ㄙㄨㄚㆵ","ㄎㄧㄚㆵ ㄐㄧㆷ˙","ㄎㄨㄚ ㄉㄧㆲ","ㄉㄧㄚㆴ˙","ㆣㄧㄜㆷ˙ ㄒㄧㄚㆷ","ㄅㆲ˪ ㄉㄨㄚ˫","ㄎㄧㆰ ㄙㄨㄣ˪","ㆠㄧㄨ˫ ㆣㆦ˫","ㄏㆦㆷ","ㄆㆲ ㄆㄞ˪","ㄇㄞˋ ㄐㄧㆦㆶ","ㄌㄨㄚ˫","ㄑㄧㄚㆷ ㄐㄧㄣˋ","ㄑㄧㄠ ㄑㄧ˫","ㄙㄜˊ","ㄅㄨㄚㆵ˙ ㄒㄧㄚㆴ˙","ㆢㄧㄚㆷ/ㄌㄧㄚㆷ","ㄎㄚ ㄎㄧㄠ","ㄗㄨㆮ˫","ㄊㄧㄠ˪ ㄊㄚㆵ","ㄆㄧㆷ ㄉㄜˋ","ㄋㆤㆷ/ㄋㄧㆷ","ㄎㄧㄣ ㄒㄧㆩ ㄙㆤ˪ ㄙㄨㆤㆷ/ㄎㄧㄣ ㄒㄧㆩ ㄙㄨㆤ˪ ㄙㆤㆷ","ㄏㄚㆵ ㄍㄧㄥˋ","ㄆㄧㆶ ㄗㄠˋ","ㄫㄧㄚˊ ㄒㄧㄣˊ","ㄏㆩ˫","ㄅㄧㆶ ㄑㄧㄚㆵ","ㄉㄧㄚㆵ˙","ㄅㄧㄤ˪","ㄙㄤ˪ ㄉㄚㆵ˙","ㄗㄨㄚ˫","ㆢㄧㄚ ㄎㆰ˪/ㄌㄧㄚ ㄎㆰ˪","ㄧㄠ ㄧㆦㆶ","ㄧㆴ","ㄋㄚˋ ㄊㄤ","ㄏㄧㆦㆶ","ㄉㆥ˫","ㄎㆦㆶ ㄌㄤˊ","ㄉㄤ˫ ㄘㆥ/ㄉㄤ˫ ㄑㆪ","ㄉㄧㄜ˪ ㄗㄜˊ","ㆣㄧㄣˊ ㄏㄨㄚㆵ/ㆣㄨㄣˊ ㄏㄨㄚㆵ","ㆡㄨㆤ˫ ㄍㄧㆰˋ/ㄌㄨㆤ˫ ㄍㄧㆰˋ","ㄘㆩ˫","ㆣㄧㆬˋ ㄒㄧㄨ˪","ㄉㄧㄣ˪ ㄙㄨㄚㆷ","ㄗㆰ˫","ㄊㄧㆷ ㄊㄚㆷ","ㄒㄧㄚㆶ","ㄑㄧㆬˊ","ㄘㄚㆶ˙","ㄘㄨㆩ˪","ㄧㄚㆵ˙ ㄌㆰˋ","ㄎㄨㄚㆷ ㄅㄚㆶ","ㄘㄨㄤ˪","ㄍㄨㆮ ㄑㄧㄚ/ㄍㄨㆪ ㄑㄧㄚ","ㄑㄧㄢˋ","ㄚ ㄙㄚ ㄅㄨㆷ ㄌㄨㆷ","ㄏㆰ˫","ㄗㄚㆴ˙ ㄘㄚˊ","ㄍㆤ ㄗㆤˊ ㄍㄧㄣ/ㄍㄨㆤ ㄗㄨㆤˊ ㄍㄨㄣ","ㄏㄧㄚ ㄍㆲˋ","ㄏㄤ˫","ㄋㄧㄚˋ ㄅㄢ","ㆣㄧㄚㆷ˙ ㆣㄨㄚ˫","ㄏㆲ ㄘㄨㆤ ㆢㄧㆵ˙ ㄆㄚㆶ˙/ㄏㆲ ㄘㆤ ㄌㄧㆵ˙ ㄆㄚㆶ˙","ㄏㄧㆫ","ㄏㄧㄤ ㄏㆬˊ","ㄏㄧㆲ ㄏㄨㄚ","ㄆㄧㄢ˪","ㄍㄧㄠ ㄫㆦ˫","ㄋㄠ˫ ㄅㄤˊ","ㄨㆵ ㄗㄨㆵ","ㄊㄜㆷ","ㄅㄧㆷ","ㄊㄧㆬ","ㄏㄜㆷ˙","ㆠㆤㆷ˙ ㆣㆤˊ","ㄇㄨㄚˊ ㄙㆩ","ㆠㄧㆶ˙ ㄎㆤ˪/ㆠㄧㆶ˙ ㄎㄨㆤ˪","ㄊㄨㆷ","ㆣㄧㄤ˪","ㄆㄧㄤ˫","ㆣㄠˊ","ㄐㄧㆴ˙","ㄎㄚㆵ","ㄘㄨㄚ˫","ㄘㄜㆷ","ㄆㄨㆵ˙","ㄨㆮˋ","ㄎㄧㄨ˫","ㄍㄠㆷ"]
    checker(list(zip(additional_c, additional)), c, c_north)